package com.sooka.system.service.impl;

import java.util.List;

import com.sooka.common.annotation.DataSource;
import com.sooka.common.core.text.Convert;
import com.sooka.common.enums.DataSourceType;
import com.sooka.framework.util.ShiroUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.sooka.system.mapper.TgjjGtjkrxxMapper;
import com.sooka.system.domain.TgjjGtjkrxx;
import com.sooka.system.service.ITgjjGtjkrxxService;

/**
 * 共同借款人信息Service业务层处理
 *
 * @author lei
 * @date 2021-11-16
 */
@Service

public class TgjjGtjkrxxServiceImpl extends Guiji_Base_Service implements ITgjjGtjkrxxService
{
    @Autowired
    private TgjjGtjkrxxMapper tgjjGtjkrxxMapper;

    /**
     * 查询共同借款人信息
     *
     * @param ID 共同借款人信息ID
     * @return 共同借款人信息
     */
    @Override
    public TgjjGtjkrxx selectTgjjGtjkrxxById(Long ID)
    {
        return tgjjGtjkrxxMapper.selectTgjjGtjkrxxById(ID);
    }

    /**
     * 查询共同借款人信息列表
     *
     * @param tgjjGtjkrxx 共同借款人信息
     * @return 共同借款人信息
     */
    @Override
    public List<TgjjGtjkrxx> selectTgjjGtjkrxxList(TgjjGtjkrxx tgjjGtjkrxx)
    {
        List ls =tgjjGtjkrxxMapper.selectTgjjGtjkrxxList(tgjjGtjkrxx);
        tgjjGtjkrxx.setInterfaceinfoId("721f43b9-9b5a-44e6-9e93-a652bcfaf195");
        tgjjGtjkrxx.setInterfaceinfoName("共享-市公积金-共同借款人信息");
        tgjjGtjkrxx.setInterfacetype("platform_interfacetype_1");
        Long deptId = ShiroUtils.getSysUser().getDept().getDeptId();
        String deptName = ShiroUtils.getSysUser().getDept().getDeptName();
        tgjjGtjkrxx.setDeptId(deptId);
        tgjjGtjkrxx.setDeptName(deptName);
        add_log(tgjjGtjkrxx);
        return ls;
    }

    /**
     * 新增共同借款人信息
     *
     * @param tgjjGtjkrxx 共同借款人信息
     * @return 结果
     */
    @Override
    public int insertTgjjGtjkrxx(TgjjGtjkrxx tgjjGtjkrxx)
    {
        return tgjjGtjkrxxMapper.insertTgjjGtjkrxx(tgjjGtjkrxx);
    }

    /**
     * 修改共同借款人信息
     *
     * @param tgjjGtjkrxx 共同借款人信息
     * @return 结果
     */
    @Override
    public int updateTgjjGtjkrxx(TgjjGtjkrxx tgjjGtjkrxx)
    {
        return tgjjGtjkrxxMapper.updateTgjjGtjkrxx(tgjjGtjkrxx);
    }

    /**
     * 删除共同借款人信息对象
     *
     * @param ids 需要删除的数据ID
     * @return 结果
     */
    @Override
    public int deleteTgjjGtjkrxxByIds(String ids)
    {
        return tgjjGtjkrxxMapper.deleteTgjjGtjkrxxByIds(Convert.toStrArray(ids));
    }

    /**
     * 删除共同借款人信息信息
     *
     * @param ID 共同借款人信息ID
     * @return 结果
     */
    @Override
    public int deleteTgjjGtjkrxxById(Long ID)
    {
        return tgjjGtjkrxxMapper.deleteTgjjGtjkrxxById(ID);
    }
}
